@@ -42,7 +42,8 @@ public:
      *  @returns The id of the new or existed merged reservation.
      */
     Q_INVOKABLE QString addReservation(const QVariant &res, const QString &resIdHint = {});
-    Q_INVOKABLE void updateReservation(const QString &resId, const QVariant &res);
+    /** Update existing reservation with post-processing. */
+    Q_INVOKABLE void updateReservation(const QString &resId, QVariant res);
     Q_INVOKABLE void removeReservation(const QString &id);
 
     /** Adds reservations after post-processing the input.
@@ -53,6 +54,13 @@ public:
     QList<QString> addReservationsWithPostProcessing(const QList<QVariant> &resData);
     Q_INVOKABLE QString addReservationWithPostProcessing(const QVariant &resData);
 
+    struct ReservationChange {
+        QString id;
+        QVariant res;
+    };
+    /** Update an entire batch, without attempting re-batching. */
+    void updateBatch(const std::vector<ReservationChange> &batch);
+
     const std::vector<QString> &batches() const;
     bool hasBatch(const QString &batchId) const;
     QString batchForReservation(const QString &resId) const;
