@@ -6,15 +6,16 @@
 #ifndef KCALENDARCORE_JNI_CALENDARDATA_H
 #define KCALENDARCORE_JNI_CALENDARDATA_H
 
+#include "kandroidextras/javatypes.h"
 #include "kandroidextras/jniobject.h"
 #include "kandroidextras/jniproperty.h"
 #include "kandroidextras/jnitypes.h"
-#include "kandroidextras/javatypes.h"
 
 JNI_TYPE(org, kde, kcalendarcore, CalendarData)
 
 /** JNI wrapper for the CalendarPlugin class. */
-class JniCalendarData {
+class JniCalendarData
+{
     JNI_OBJECT(JniCalendarData, org::kde::kcalendarcore::CalendarData)
 public:
     JNI_PROPERTY(jlong, id)
