@@ -20,15 +20,12 @@ MatrixManager::MatrixManager(QObject *parent)
         Q_EMIT userIdChanged();
         Q_EMIT connectionChanged();
         setInfoString(i18n("Syncing…"));
-        connect(
-            m_accountRegistry.accounts()[0],
-            &Connection::syncDone,
-            this,
-            [this]() {
-                setInfoString({});
-                m_accountRegistry.accounts()[0]->stopSync();
-            },
-            Qt::SingleShotConnection);
+        auto connection = m_accountRegistry.accounts()[0];
+        connect(connection, &Connection::syncDone, this, [this](){
+            setInfoString({});
+        }, Qt::SingleShotConnection);
+
+        connect(connection, &Connection::sessionVerified, this, &MatrixManager::sessionVerifiedChanged, Qt::QueuedConnection);
     });
     connect(&m_accountRegistry, &AccountRegistry::rowsRemoved, this, [this]() {
         Q_EMIT connectedChanged();
@@ -54,18 +51,13 @@ void MatrixManager::login(const QString &matrixId, const QString &password)
 
     auto connection = new Connection(this);
     connection->resolveServer(matrixId);
-    connect(
-        connection,
-        &Connection::loginFlowsChanged,
-        this,
-        [this, connection, matrixId, password]() {
-            if (!connection->supportsPasswordAuth()) {
-                setInfoString(i18n("This server does not support logging in using a password"));
-            }
-            auto username = matrixId.mid(1, matrixId.indexOf(QLatin1Char(':')) - 1);
-            connection->loginWithPassword(username, password, m_deviceName, {});
-        },
-        Qt::SingleShotConnection);
+    connect(connection, &Connection::loginFlowsChanged, this, [this, connection, matrixId, password]() {
+        if (!connection->supportsPasswordAuth()) {
+            setInfoString(i18n("This server does not support logging in using a password"));
+        }
+        auto username = matrixId.mid(1, matrixId.indexOf(QLatin1Char(':')) - 1);
+        connection->loginWithPassword(username, password, m_deviceName, {});
+    }, Qt::SingleShotConnection);
 
     connect(connection, &Connection::connected, this, [this, connection] {
         AccountSettings account(connection->userId());
@@ -75,13 +67,15 @@ void MatrixManager::login(const QString &matrixId, const QString &password)
         account.setDeviceName(m_deviceName);
         account.sync();
         m_accountRegistry.add(connection);
-    });
+        connection->setLazyLoading(true);
+        connection->syncLoop();
+    }, Qt::SingleShotConnection);
 
     connect(connection, &Connection::loginError, this, [this](const QString &message) {
         setInfoString(message);
     });
 
-    setInfoString(i18n("Logging in"));
+    setInfoString(i18n("Logging in…"));
 }
 
 QString MatrixManager::infoString() const
@@ -94,6 +88,15 @@ bool MatrixManager::connected() const
     return m_accountRegistry.count() > 0;
 }
 
+bool MatrixManager::isVerifiedSession() const
+{
+    if (!connected()) {
+        return false;
+    }
+    const auto c = connection();
+    return c->isVerifiedDevice(c->userId(), c->deviceId());
+}
+
 void MatrixManager::setInfoString(const QString &infoString)
 {
     m_infoString = infoString;
@@ -108,6 +111,7 @@ QString MatrixManager::userId() const
 void MatrixManager::logout()
 {
     m_accountRegistry.accounts()[0]->logout();
+    setInfoString(i18n("Logged out"));
 }
 
 Quotient::Connection *MatrixManager::connection() const
